# -*- coding: utf-8 -*-
from setuphelpers import *
import platform

# Declaring specific app values (TO CHANGE)
app_name = "Tixeo Communication Client"
bin_zip_string = "TixeoClient_%s.zip"
app_sys_dir_short = makepath(programfiles32, "Tixeo Soft", "Communication")
app_sys_dir = makepath(app_sys_dir_short, "Client")


def update_package():
    print("Download/Update package content from upstream binary sources")

    # Getting proxy informations from WAPT settings
    proxy = {}
    if platform.system() == "Windows" and isfile(makepath(user_local_appdata(), "waptconsole", "waptconsole.ini")):
        proxywapt = inifile_readstring(makepath(user_local_appdata(), "waptconsole", "waptconsole.ini"), "global", "http_proxy")
        if proxywapt:
            proxy = {"http": proxywapt, "https": proxywapt}

    # Specific app values
    bin_zip_name = "TixeoClient.zip"
    url_dl_zip = "https://cloud.tixeo.com/meet-static/dl/client/TixeoClient.zip"
    # url_dl = 'https://cloud.tixeo.com/meet-static/dl/client/TixeoClientW3D.exe'

    print("Download url is: " + url_dl_zip)

    # Downloading latest binaries
    if isfile(bin_zip_name):
        remove_file(bin_zip_name)
    if not isfile(bin_zip_name):
        print("Downloading: " + bin_zip_name)
        wget(url_dl_zip, bin_zip_name, proxies=proxy)

        # Unzip to get file version
        unzip(bin_zip_name, target="tixeo_temp", filenames=r"TixeoClient\W3DClient.exe")

        # Checking version from file
        version_from_file = get_file_properties(r"tixeo_temp\TixeoClient\W3DClient.exe")["FileVersion"]
        version = version_from_file
        latest_bin_zip = bin_zip_string % version
        if isfile(latest_bin_zip):
            remove_file(latest_bin_zip)
        os.rename(bin_zip_name, latest_bin_zip)
        print("Verified latest " + app_name + " version is: " + version)

        # Removing temp folder
        remove_tree("tixeo_temp")

        # Changing version of the package
        control.version = "%s-%s" % (version, int(control.version.split("-", 1)[1]) + 1)
        control.save_control_to_wapt()
        print("Changing version to " + control.version + " in WAPT\\control")
        print("Update package done. You can now build-upload your package")
    else:
        print("This package is already up-to-date")

    # Deleting outdated binaries
    for bin_in_dir in glob.glob("*.exe") or glob.glob("*.msi") or glob.glob("*.zip"):
        if bin_in_dir != latest_bin_zip:
            print("Outdated binary: " + bin_in_dir + " Deleted")
            remove_file(bin_in_dir)
